@@ -4,8 +4,8 @@ predict.se.blm <- function(object,newdata,se=FALSE){
     newdata <- object@data
     
   if(class(object)=="lexpit"){
-    X <- model.matrix(object@formula.linear,newdata)
-    Z <- model.matrix(object@formula.expit,newdata)
+    X <- model.matrix(update(object@formula.linear,NULL~.),newdata)
+    Z <- model.matrix(update(object@formula.expit,NULL~.),newdata)
     
     x.has.intercept <- attr(terms(object@formula.linear),"intercept")==1
     
@@ -17,7 +17,7 @@ predict.se.blm <- function(object,newdata,se=FALSE){
     p <- X%*%object@coef.linear+expit(Z%*%object@coef.expit)
   }
   else{
-    X <- model.matrix(object@formula,newdata)
+    X <- model.matrix(update(object@formula,NULL~.),newdata)
     p <- X%*%object@coef
   }
   
@@ -42,4 +42,4 @@ predict.se.blm <- function(object,newdata,se=FALSE){
 }
 
 setMethod("predict","blm",predict.se.blm)
-setMethod("predict","lexpit",predict.se.blm)
\ No newline at end of file
+setMethod("predict","lexpit",predict.se.blm)
